==> viha-5.15.tar.gz: viha-5.15/jarjesto-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);
$table = "hlo";

include "common.php";

$jarjesto_id = get_nro_0('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');

echo "
<html>
<head>
 <title>VIHA - Jrjestn hlytysryhm</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestn hlytysryhmn muodostaminen, " . jarjesto($jarjesto_id)
. "</h1>
";

taktiset_linkit();

$take = get_txt('take');
$take_all = get_txt('take_all');
$release = get_txt('release');
$release_all = get_txt('release_all');
$show = get_nro('show');

# kuka vaan voi ottaa henkiln samalta alueelta - kytettvyyskysymys
if ($hlo_id != 0)
  oltava_alueella($file, "hlo", $hlo_id);
oltava_alueella($file, "jarjesto", $jarjesto_id);

if (($take != '') && saa_tehda("$file:take")) {
  $hlo_jarjesto = ota_yksi("SELECT jarjesto_id FROM hlo WHERE id = $hlo_id");
  if ($hlo_jarjesto == $jarjesto_id) {
    ilmoita_jos_tarpeen($hlo_id);
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET halyssa=1,
           ts='$now'
       WHERE id=$hlo_id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki("Otettu hlytysryhmn " . ota_nimi($hlo_id));
#    add_hlo_ajat($hlo_id);
    echo "<p>Henkil otettu hlytysryhmn.\n";
  } else {
    # hlo_jarjesto != jarjesto_id
    echo "<p>Henkiln ja hlytysryhmn jrjestt eivt ole samat.\n";
  }
 }

if (($take_all != '') && saa_tehda("$file:take_all")) {
  $now = date('Y-m-d H:i:s');
  $sql =
    "UPDATE hlo
     SET halyssa=1,
         ts='$now'
     WHERE jarjesto_id=$jarjesto_id";
    $result = my_mysql_query ($sql,true,true);
#    taktinen_loki("Otettu hlytysryhmn " . ota_nimi($hlo_id));
#    add_hlo_ajat($hlo_id);
    echo "<p>Kaikki otettu hlytysryhmn.\n";
 }

if (($release != '') && saa_tehda("$file:release")) {
  $hlo_jarjesto = ota_yksi("SELECT jarjesto_id FROM hlo WHERE id = $hlo_id");
  if ($hlo_jarjesto == $jarjesto_id) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET halyssa=0,
           ts='$now'
       WHERE id=$hlo_id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki("Vapautettu hlytysryhmst " . ota_nimi($hlo_id));
 #   add_hlo_ajat($hlo_id);
    echo "<p>Henkil vapautettu hlytysryhmst.\n";
  } else {
    # hlo_jarjesto != jarjesto_id
    echo "<p>Henkiln ja hlytysryhmn jrjestt eivt ole samat.\n";
  }
 }

if (($release_all != '') && saa_tehda("$file:release_all")) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET halyssa=0,
           ts='$now'
       WHERE jarjesto_id=jarjesto_id";
    $result = my_mysql_query ($sql,true,true);
 #   taktinen_loki("Vapautettu hlytysryhmst " . ota_nimi($hlo_id));
 #   add_hlo_ajat($hlo_id);
    echo "<p>Kaikki vapautettu hlytysryhmst.\n";
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT hlo.id, hlo.nimi, hlo.puhelin, hlo_tila.hlo_tila,
          hlo.ra, hlo.ts, hlo.alue_id, hlo.paivystys_id, ryhma.kutsu, halyssa
   FROM hlo, hlo_tila, ryhma
   WHERE hlo_tila.id = hlo.hlo_tila_id
         AND ryhma.id = hlo.ryhma_id
         AND jarjesto_id = $jarjesto_id
   ORDER BY hlo.nimi";

$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Nimi<TH>Operaatio<TH>Ryhm"
    . "<TH>Muutettu<TH>Tila<TH>Listieto\n";
  echo "<th>"
    . "<a href=\"jarjesto-takt-1.php?"
    . "jarjesto_id=$jarjesto_id&show=$show&"
    . "release_all=VAPAUTA\">VAPAUTA KAIKKI</a>\n";
  echo " "
    . "<a href=\"jarjesto-takt-1.php?"
    . "jarjesto_id=$jarjesto_id&show=$show&"
    . "take_all=OTA\">OTA KAIKKI</a>\n";
  while ($a = mysql_fetch_array($result)) {
    if (permission_alue_id($herja,$a['alue_id'],false) == 2)
      continue;
    $p_id = $a['paivystys_id'];
    $s_id = s('paivystys');
    $halyssa = $a['halyssa'];
    if (($show == '')
	|| ($show == '1' && (! $halyssa))
	|| ($show == '3' && ($halyssa))
	) {
      echo "<TR>", "<TD>$a[nimi]",
	"<td>" . nayta_operaatio($p_id),
	"<TD>$a[kutsu]", 
	"<TD>$a[ts]", 
	"<td>$a[hlo_tila]",
	"<TD>$a[ra]";
      if ($halyssa) {
	echo "<td>"
	  . "<a href=\"jarjesto-takt-1.php?"
	  . "hlo_id=$a[id]&jarjesto_id=$jarjesto_id&show=$show&"
	  . "release=VAPAUTA\">VAPAUTA</a>\n";
      } else {
	echo "<td>"
	  . "<a href=\"jarjesto-takt-1.php?"
	  . "hlo_id=$a[id]&jarjesto_id=$jarjesto_id&show=$show&"
	  . "take=OTA\">"
	  . "OTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } 

echo "</form>\n";

echo "
<p>Voit ottaa henkiln mukaan hlytysryhmn klikkaamalla kohtaa OTA
(toimii mys muihin operaatioihin merkittyihin henkilihin).
<p>Henkil vapautetaan hlytysryhmst klikkaamalla VAPAUTA.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation henkilkunta on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"jarjesto-takt-1.php?show=&jarjesto_id=$jarjesto_id\">
  Nyt kaikki
 </a> (oletus)
<li><a href=\"jarjesto-takt-1.php?show=1&jarjesto_id=$jarjesto_id\">
  Nyt vain henkilt jotka eivt ole hlytysryhmss
 </a>
<li><a href=\"jarjesto-takt-1.php?show=3&jarjesto_id=$jarjesto_id\">
  Nyt vain henkilt jotka ovat hlytysryhmss
 </a>
<li><a href=\"jarjesto-takt-2.php?show=4&jarjesto_id=$jarjesto_id\">
  Valintaruutuversio (rasti ruutuun)
 </a>
</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto-takt-1.php,v 1.16 2009/06/07 18:11:37 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/jarjesto-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);
$table = "hlo";

include "common.php";
include "hlo-ok.php";

$jarjesto_id = get_nro_0('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');

echo "
<html>
<head>
 <title>VIHA - Jrjestn hlytysryhm</title>
</head>
" . body_bgcolor() . "
<h1>Jrjestn hlytysryhmn muodostaminen, " . jarjesto($jarjesto_id)
. "</h1>
";

taktiset_linkit();

$take = get_txt('take');
$take_all = get_txt('take_all');
$release = get_txt('release');
$release_all = get_txt('release_all');
$show = get_nro('show');

# kuka vaan voi ottaa henkiln samalta alueelta - kytettvyyskysymys
if ($hlo_id != 0)
  oltava_alueella($file, "hlo", $hlo_id);
oltava_alueella($file, "jarjesto", $jarjesto_id);

if (($take != '') && saa_tehda("$file:take")) {
  $ret = ota_hlo_paivystys($herja, $hlo_id, s("paivystys"));
  if ($ret != 2) {
    $tmp_nimi = ota_nimi($hlo_id);
    tehty("Otettu $tmp_nimi thn operaatioon.");
  }
  p_herja($ret,$herja);
 }

if (($take_all != '') && saa_tehda("$file:take_all")) {
  $sql =
    "SELECT id,nimi
     FROM hlo
     WHERE jarjesto_id = $jarjesto_id
           AND halyssa = 0
           AND paivystys_id = 1
     ORDER BY nimi";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($a = mysql_fetch_array($result)) {
      $ret = ota_hlo_paivystys($herja, $a['id'], s("paivystys"));
      if ($ret != 2) {
	$tmp_nimi = ota_nimi($a['id']);
	tehty("Otettu $tmp_nimi thn operaatioon.");
      }
      p_herja($ret,$herja);
    }
  }
 }

if (($release != '') && saa_tehda("$file:release")) {
  $ret = vapauta_hlo_paivystys($herja,$hlo_id,s("paivystys"));
  if ($ret != 2) {
    $tmp_nimi = ota_nimi($hlo_id);
    tehty("Vapautettu $tmp_nimi.");
  }
  p_herja($ret,$herja);
 }

if (($release_all != '') && saa_tehda("$file:release_all")) {
  vapauta_kaikki($jarjesto_id, s("paivystys"));
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT hlo.id, hlo.nimi, hlo.puhelin, hlo_tila.hlo_tila,
          hlo.ra, hlo.ts, hlo.alue_id, hlo.paivystys_id, ryhma.kutsu, halyssa
   FROM hlo, hlo_tila, ryhma
   WHERE hlo_tila.id = hlo.hlo_tila_id
         AND ryhma.id = hlo.ryhma_id
         AND jarjesto_id = $jarjesto_id
   ORDER BY hlo.nimi";

$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_vaalsin()
    . "<TH>Nimi<TH>Operaatio<TH>Ryhm"
    . "<TH>Muutettu<TH>Tila<TH>Listieto\n";
  echo "<th>"
    . "<a href=\"jarjesto-takt-1.php?"
    . "jarjesto_id=$jarjesto_id&show=$show&"
    . "release_all=VAPAUTA\">VAPAUTA KAIKKI</a>\n";
  echo " "
    . "<a href=\"jarjesto-takt-1.php?"
    . "jarjesto_id=$jarjesto_id&show=$show&"
    . "take_all=OTA\">OTA KAIKKI</a>\n";
  while ($a = mysql_fetch_array($result)) {
    if (permission_alue_id($herja,$a['alue_id'],false) == 2)
      continue;
    $p_id = $a['paivystys_id'];
    $s_id = s('paivystys');
    $halyssa = $a['halyssa'];
    if (($show == '')
	|| ($show == '1' && (! $halyssa))
	|| ($show == '3' && ($halyssa))
	) {
      echo "<TR>", "<TD>$a[nimi]",
	"<td>" . nayta_operaatio($p_id),
	"<TD>$a[kutsu]", 
	"<TD>$a[ts]", 
	"<td>$a[hlo_tila]",
	"<TD>$a[ra]";
      if ($halyssa) {
	echo "<td>"
	  . "<a href=\"jarjesto-takt-1.php?"
	  . "hlo_id=$a[id]&jarjesto_id=$jarjesto_id&show=$show&"
	  . "release=VAPAUTA\">VAPAUTA</a>\n";
      } else {
	echo "<td>"
	  . "<a href=\"jarjesto-takt-1.php?"
	  . "hlo_id=$a[id]&jarjesto_id=$jarjesto_id&show=$show&"
	  . "take=OTA\">"
	  . "OTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } 

echo "</form>\n";

echo "
<p>Voit ottaa henkiln mukaan hlytysryhmn klikkaamalla kohtaa OTA
(toimii mys muihin operaatioihin merkittyihin henkilihin).
<p>Henkil vapautetaan hlytysryhmst klikkaamalla VAPAUTA.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation henkilkunta on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"jarjesto-takt-1.php?show=&jarjesto_id=$jarjesto_id\">
  Nyt kaikki
 </a> (oletus)
<li><a href=\"jarjesto-takt-1.php?show=1&jarjesto_id=$jarjesto_id\">
  Nyt vain henkilt jotka eivt ole hlytysryhmss
 </a>
<li><a href=\"jarjesto-takt-1.php?show=3&jarjesto_id=$jarjesto_id\">
  Nyt vain henkilt jotka ovat hlytysryhmss
 </a>
<li><a href=\"jarjesto-takt-2.php?show=4&jarjesto_id=$jarjesto_id\">
  Valintaruutuversio (rasti ruutuun)
 </a>
</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: jarjesto-takt-1.php,v 1.20 2009/10/01 16:05:35 riku Exp $ -->
